#[non_exhaustive]pub enum CapabilitySupport {
Unsupported,
ConfigDependent,
Supported,
}Expand description
Whether a backend implementation can handle a feature.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
The Chimera backend implementation does not support this feature.
ConfigDependent
Support depends on the selected backend config or session mode.
Supported
The feature is supported unconditionally by this backend implementation.
Implementations
Sourceimpl CapabilitySupport
impl CapabilitySupport
pub fn is_supported(self) -> bool