SessionConfigBuilder

Struct SessionConfigBuilder 

pub struct SessionConfigBuilder<C, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<C, S: State> SessionConfigBuilder<C, S>

pub fn build(self) -> SessionConfig<C>
where S: IsComplete,

Finish building and return the requested object

pub fn model( self, value: impl Into<String>, ) -> SessionConfigBuilder<C, SetModel<S>>
where S::Model: IsUnset,

Optional (Some / Option setters).

pub fn maybe_model( self, value: Option<impl Into<String>>, ) -> SessionConfigBuilder<C, SetModel<S>>
where S::Model: IsUnset,

Optional (Some / Option setters).

pub fn cwd(self, value: PathBuf) -> SessionConfigBuilder<C, SetCwd<S>>
where S::Cwd: IsUnset,

Optional (Some / Option setters).

pub fn maybe_cwd( self, value: Option<PathBuf>, ) -> SessionConfigBuilder<C, SetCwd<S>>
where S::Cwd: IsUnset,

Optional (Some / Option setters).

pub fn additional_dirs( self, value: Vec<PathBuf>, ) -> SessionConfigBuilder<C, SetAdditionalDirs<S>>
where S::AdditionalDirs: IsUnset,

Optional (Some / Option setters). Default: <Vec<PathBuf> as Default>::default().

pub fn maybe_additional_dirs( self, value: Option<Vec<PathBuf>>, ) -> SessionConfigBuilder<C, SetAdditionalDirs<S>>
where S::AdditionalDirs: IsUnset,

Optional (Some / Option setters). Default: <Vec<PathBuf> as Default>::default().

pub fn env( self, value: HashMap<String, String>, ) -> SessionConfigBuilder<C, SetEnv<S>>
where S::Env: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

pub fn maybe_env( self, value: Option<HashMap<String, String>>, ) -> SessionConfigBuilder<C, SetEnv<S>>
where S::Env: IsUnset,

Optional (Some / Option setters). Default: <HashMap<String, String> as Default>::default().

pub fn env_remove( self, value: HashSet<String>, ) -> SessionConfigBuilder<C, SetEnvRemove<S>>
where S::EnvRemove: IsUnset,

Optional (Some / Option setters). Default: <HashSet<String> as Default>::default().

Inherited environment variables to remove from the subprocess. Only meaningful when the subprocess inherits the parent environment.

pub fn maybe_env_remove( self, value: Option<HashSet<String>>, ) -> SessionConfigBuilder<C, SetEnvRemove<S>>
where S::EnvRemove: IsUnset,

Optional (Some / Option setters). Default: <HashSet<String> as Default>::default().

Inherited environment variables to remove from the subprocess. Only meaningful when the subprocess inherits the parent environment.

pub fn max_turns(self, value: u32) -> SessionConfigBuilder<C, SetMaxTurns<S>>
where S::MaxTurns: IsUnset,

Optional (Some / Option setters).

pub fn maybe_max_turns( self, value: Option<u32>, ) -> SessionConfigBuilder<C, SetMaxTurns<S>>
where S::MaxTurns: IsUnset,

Optional (Some / Option setters).

pub fn system_prompt( self, value: impl Into<String>, ) -> SessionConfigBuilder<C, SetSystemPrompt<S>>
where S::SystemPrompt: IsUnset,

Optional (Some / Option setters).

pub fn maybe_system_prompt( self, value: Option<impl Into<String>>, ) -> SessionConfigBuilder<C, SetSystemPrompt<S>>
where S::SystemPrompt: IsUnset,

Optional (Some / Option setters).

pub fn backend(self, value: C) -> SessionConfigBuilder<C, SetBackend<S>>
where S::Backend: IsUnset,

Required.